==> EnhancedXSPF-0.4.zip: EnhancedXSPF/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Enhanced XSPF';
$lang['postinstall'] = 'De module is met succes geinstalleerd';
$lang['postuninstall'] = 'De module is met succes ge-deinstalleerd';
$lang['really_uninstall'] = 'Deze module de-installeren?';
$lang['audit_module_install'] = 'Module versie %s geinstalleerd.';
$lang['audit_module_upgrade'] = 'Module bijgewerkt naar versie %s.';
$lang['audit_module_uninstall'] = 'Module gedeinstalleerd';
$lang['audit_admin_playlist_added'] = 'Playlist toegevoegd';
$lang['audit_admin_playlist_changed'] = 'Playlist aangepast';
$lang['audit_admin_playlist_songs_saved'] = 'Playlist nummers opgeslagen';
$lang['audit_admin_playlist_deleted'] = 'Playlist verwijderd';
$lang['audit_admin_prefs_changed'] = 'Module voorkeuren gewijzigd';
$lang['title_admintab_prefs'] = 'Module Voorkeuren';
$lang['title_admintab_songs'] = 'Nummers';
$lang['title_admintab_playlists'] = 'Playlists';
$lang['id'] = 'Id';
$lang['name'] = 'Naam';
$lang['description'] = 'Omschrijving';
$lang['songs'] = 'Nummers';
$lang['playlist'] = 'Playlist';
$lang['title_link_add_playlist'] = 'Playlist Toevoegen';
$lang['title_link_edit_songs'] = 'Nummers Bewerken';
$lang['title_link_add_uploads_categories'] = 'Uploads categorie toevoegen';
$lang['title_songs_in_playlist'] = 'Nummers in playlist';
$lang['title_available_songs'] = 'Beschikbare nummers';
$lang['alert_delete_playlist'] = 'Playlist %s verwijderen?';
$lang['header_default_player_options'] = 'Standaard speler opties';
$lang['header_add_playlist'] = 'Playlist toevoegen';
$lang['header_add_playlist_songs'] = 'Playlist Nummers Toevoegen';
$lang['header_edit_playlist'] = 'Playlist Aanpassen';
$lang['header_edit_playlist_songs'] = 'Playlist Nummers Aanpassen';
$lang['header_admin_playlists'] = 'Playlists Beheren';
$lang['dropdown_item_player_slim'] = 'Minimaal';
$lang['dropdown_item_player_extended'] = 'Uitgebreid';
$lang['label_admin_prefs_extended_player_url'] = 'extended_player_url';
$lang['label_admin_prefs_slim_player_url'] = 'slim_player_url';
$lang['label_admin_prefs_player_width'] = 'player_width';
$lang['label_admin_prefs_slim_player_height'] = 'slim_player_height';
$lang['label_admin_prefs_extended_player_height'] = 'extended_player_height';
$lang['label_admin_prefs_autoresume'] = 'autoresume';
$lang['label_admin_prefs_autoplay'] = 'autoplay';
$lang['label_admin_prefs_autoload'] = 'autoload';
$lang['label_admin_prefs_shuffle'] = 'shuffle';
$lang['label_admin_prefs_repeat'] = 'repeat';
$lang['label_admin_prefs_player'] = 'player';
$lang['msg_no_changes'] = 'Geen wijzigingen';
$lang['msg_playlist_songs_updated'] = 'Playlist nummers bijgewerkt';
$lang['msg_playlist_updated'] = 'Playlist bijgewerkt';
$lang['msg_set_preference'] = 'Voorkeur %s bijgewerkt';
$lang['msg_playlist_added'] = 'Playlist toegevoegd';
$lang['err_access_denied'] = 'Toegang geweigerd. Controleer uw permissies.';
$lang['err_admin_add_playlist_no_name'] = 'Fout: geen naam opgegeven';
$lang['err_playlist_not_found'] = 'Fout: de opgegeven playlist is niet gevonden';
$lang['err_uploads_module_not_installed'] = 'Fout: de Uploads module is niet geinstalleerd';
$lang['err_no_uploads_categories_defined'] = 'Fout: er zijn geen Uploads categorieen';
$lang['err_no_mp3s_found'] = 'fout: geen .mp3 bestanden gevonden in de Uploads categorieen';
$lang['err_no_playlist_specified'] = 'Fout: geen playlist opgegeven';
$lang['err_no_song_specified'] = 'Fout: geen nummer (upload ID) opgegeven';
$lang['err_no_playlist_or_song_specified'] = 'fout: geen nummer of playlist parameter opgegeven';
$lang['help_drag_drop'] = 'gebruik &quot;drag &amp; drop&quot; om nummers toe te voegen en te verwijderen en om de playlist nummervolgorde te bepalen.';
$lang['help_parameter_playlist'] = 'playlist id to play';
$lang['help_parameter_song'] = 'upload_id of a single song to play instead of a playlist';
$lang['help_parameter_song_title'] = 'The text to replace the players default&#039;s. Only used when the song parameter is also supplied.';
$lang['help_parameter_player'] = 'the xspf player version to use (slim or extended)';
$lang['help_parameter_extended_player_url'] = 'the url of the extended version of the xspf player';
$lang['help_parameter_slim_player_url'] = 'the url of the slim version of the xspf player';
$lang['help_parameter_player_width'] = 'width of the player in pixels';
$lang['help_parameter_slim_player_height'] = 'height of the slim player in pixels';
$lang['help_parameter_extended_player_height'] = 'height of the extended player in pixels';
$lang['help_parameter_autoresume'] = 'boolean value that makes the player remember it&#039;s position';
$lang['help_parameter_autoplay'] = 'boolean value that makes the playlist load and the music start without the initial user click';
$lang['help_parameter_autoload'] = 'boolean value that makes the playlist load without the initial user click';
$lang['help_parameter_repeat_playlist'] = 'boolean value to repeat the playlist';
$lang['help_parameter_alpha'] = 'percent of color change, only works with custom color';
$lang['help_parameter_alphabetize'] = 'boolean value to alphabetize playlist';
$lang['help_parameter_buffer'] = 'seconds to preload video before playing, exclude for automatic';
$lang['help_parameter_color'] = 'six digit hex value to change the players color';
$lang['help_parameter_gotoany'] = 'boolean value that forces travel to unknown URLs';
$lang['help_parameter_image'] = 'url for a jpg image that is shown when autoplay is off';
$lang['help_parameter_info_button_text'] = 'the text to display on the info link, <a href=http://musicplayer.sourceforge.net/test/info-test.html>see this page</a>';
$lang['help_parameter_infourl'] = 'global info url for all songs, replaces playlist info urls';
$lang['help_parameter_loadurl'] = 'url linking to a text file containing all variables. cuts down on html coding and file sizes, one file can be used by many players';
$lang['help_parameter_load_message'] = 'message displayed after autoload';
$lang['help_parameter_main_image'] = 'global image url, replaces all playlist images';
$lang['help_parameter_mainurl'] = 'right-click &quot;about&quot; url';
$lang['help_parameter_no_continue'] = 'boolean value to turn off automatic song changing';
$lang['help_parameter_player_title'] = 'the text to replace the players default&#039;s';
$lang['help_parameter_repeat'] = 'boolean value to set repeat';
$lang['help_parameter_setup'] = 'boolean value to turn on special manager features such as auto-update. more to come.';
$lang['help_parameter_shuffle'] = 'boolean value to set shuffle';
$lang['help_parameter_start_track'] = 'track number for beginning track';
$lang['help_parameter_statsurl'] = 'url to an external script that can collect POST values. Can collect playSong and annotation';
$lang['help_parameter_timedisplay'] = 'numerical value to show time counter; 0:off, 1:all, 2:elapsed, 3:duration, 4:countdown';
$lang['help_parameter_useId3'] = 'boolean value that forces id3 tag use in the slim player. Can be helpful, but not recommended';
$lang['help_parameter_volume_level'] = 'starting volume level';
$lang['event_info_XSPFSongAdded'] = 'An event generated when a song is added';
$lang['event_help_XSPFSongAdded'] = '<p>An event generated when a song is added</p>
<h4>Parameters</h4>
<ul>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongChanged'] = 'An event generated when a song is modified';
$lang['event_help_XSPFSongChanged'] = '<p>An event generated when a song is modified</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongDeleted'] = 'An event generated when a song is deleted';
$lang['event_help_XSPFSongDeleted'] = '<p>An event generated when a song is deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
</ul> 
';
$lang['moddescription'] = 'Enhanced XSPF Web Music Player - play MP3 on your CMS Made Simple website';
$lang['changelog'] = '<ul>
	<li>Version 0.1 Januari 2007 (dittmann). 
		<ul>
		    <li>Initial module release</li>
		</ul>
	</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>With this module you can manage a XSPF playlist to use with a xspf music player. Enhanced XSPF player is provided with the module.</p>
<h3>How Do I Use It</h3>
<p>Upload the mp3 files you want to play using the Uploads module.</p>
<p>
	<strong>To play a single song</strong><br />
	Provide the file ID from the Uploads module as song parameter - the module call will look something like this: {cms_module module=EnhancedXSPF song=4}
<p>
	<strong>To play a playlist</strong><br />
	Create one or more playlists from the module admin and include the module in your template providing the playlist id to use - the module call will look something like this: {cms_module module=EnhancedXSPF playlist=1}
	
</p>
<p>
	When you include the player in a frame (for playback without pauses when the page is changed) you can call the playlist seperately, providing a playlist parameter.<br />
	The playlist_url would look something like this: http://www.example.com/modules/EnhancedXSPF/playlist.xml.php?playlist=1
</p>
<h3>XSPF Player parameters</h3>
<p>
	All player parameters (see also xspf/xspfdoc.html inside the module directory) can be passed to the module and will be used in the player call.<br />
</p>
<h3>Support</h3>
<p>There is a number of resources available to help you with this module:
<ul>
<li>Additional discussion of this module may also be found in the <a href=&quot;http://forum.cmsmadesimple.org&quot;>CMS Made Simple Forums</a>.</li>
<li>The author, Dick Ittmann, can often be found as DeeEye in the <a href=&quot;http://cmsmadesimple.org/main/support/IRC&quot;>CMS IRC Channel</a>.</li>
</ul>
</p>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2007, Dick Ittmann. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&quot;http://www.gnu.org/licenses/licenses.html#GPL&quot;>GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utma'] = '156861353.596605968.1147215934.1170269911.1170635381.259';
$lang['utmz'] = '156861353.1170269911.258.61.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmc'] = '156861353';
?>

==> EnhancedXSPF-0.5.1.zip: EnhancedXSPF/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'Enhanced XSPF';
$lang['postinstall'] = 'De module is met succes geinstalleerd';
$lang['postuninstall'] = 'De module is met succes ge-deinstalleerd';
$lang['really_uninstall'] = 'Deze module de-installeren?';
$lang['audit_module_install'] = 'Module versie %s geinstalleerd.';
$lang['audit_module_upgrade'] = 'Module bijgewerkt naar versie %s.';
$lang['audit_module_uninstall'] = 'Module gedeinstalleerd';
$lang['audit_admin_playlist_added'] = 'Playlist toegevoegd';
$lang['audit_admin_playlist_changed'] = 'Playlist aangepast';
$lang['audit_admin_playlist_songs_saved'] = 'Playlist nummers opgeslagen';
$lang['audit_admin_playlist_deleted'] = 'Playlist verwijderd';
$lang['audit_admin_prefs_changed'] = 'Module voorkeuren gewijzigd';
$lang['title_admintab_prefs'] = 'Module Voorkeuren';
$lang['title_admintab_songs'] = 'Nummers';
$lang['title_admintab_playlists'] = 'Afspeellijsten';
$lang['id'] = 'Id';
$lang['name'] = 'Naam';
$lang['description'] = 'Omschrijving';
$lang['songs'] = 'Nummers';
$lang['playlist'] = 'Afspeellijst';
$lang['title_link_add_playlist'] = 'Playlist Toevoegen';
$lang['title_link_edit_songs'] = 'Nummers Bewerken';
$lang['title_link_add_uploads_categories'] = 'Uploads categorie toevoegen';
$lang['title_songs_in_playlist'] = 'Nummers in playlist';
$lang['title_available_songs'] = 'Beschikbare nummers';
$lang['alert_delete_playlist'] = 'Playlist %s verwijderen?';
$lang['header_module_options'] = 'Module Opties';
$lang['header_parameter_defaults'] = 'Standaard Parameter';
$lang['header_add_playlist'] = 'Playlist toevoegen';
$lang['header_add_playlist_songs'] = 'Playlist Nummers Toevoegen';
$lang['header_edit_playlist'] = 'Playlist Aanpassen';
$lang['header_edit_playlist_songs'] = 'Playlist Nummers Aanpassen';
$lang['header_admin_playlists'] = 'Playlists Beheren';
$lang['dropdown_item_player_slim'] = 'Minimaal';
$lang['dropdown_item_player_extended'] = 'Uitgebreid';
$lang['label_admin_prefs_extended_player_url'] = 'extended_player_url';
$lang['label_admin_prefs_slim_player_url'] = 'slim_player_url';
$lang['label_admin_prefs_player_width'] = 'player_width';
$lang['label_admin_prefs_slim_player_height'] = 'slim_player_height';
$lang['label_admin_prefs_extended_player_height'] = 'extended_player_height';
$lang['label_admin_prefs_autoresume'] = 'autoresume';
$lang['label_admin_prefs_autoplay'] = 'autoplay';
$lang['label_admin_prefs_autoload'] = 'autoload';
$lang['label_admin_prefs_shuffle'] = 'shuffle';
$lang['label_admin_prefs_repeat'] = 'repeat';
$lang['label_admin_prefs_player'] = 'player';
$lang['label_admin_prefs_count_downloads'] = 'count_downloads';
$lang['label_admin_prefs_no_direct_downloads'] = 'no_direct_downloads';
$lang['msg_no_changes'] = 'Geen wijzigingen';
$lang['msg_playlist_songs_updated'] = 'Playlist nummers bijgewerkt';
$lang['msg_playlist_updated'] = 'Playlist bijgewerkt';
$lang['msg_set_preference'] = 'Voorkeur %s bijgewerkt';
$lang['msg_playlist_added'] = 'Playlist toegevoegd';
$lang['err_access_denied'] = 'Toegang geweigerd. Controleer uw permissies.';
$lang['err_admin_add_playlist_no_name'] = 'Fout: geen naam opgegeven';
$lang['err_playlist_not_found'] = 'Fout: de opgegeven playlist is niet gevonden';
$lang['err_uploads_module_not_installed'] = 'Fout: de Uploads module is niet geinstalleerd';
$lang['err_no_uploads_categories_defined'] = 'Fout: er zijn geen Uploads categorieen';
$lang['err_no_mp3s_found'] = 'fout: geen .mp3 bestanden gevonden in de Uploads categorieen';
$lang['err_no_playlist_specified'] = 'Fout: geen playlist opgegeven';
$lang['err_no_song_specified'] = 'Fout: geen nummer (upload ID) opgegeven';
$lang['err_no_playlist_or_song_specified'] = 'fout: geen nummer of playlist parameter opgegeven';
$lang['help_drag_drop'] = 'gebruik &quot;drag &amp; drop&quot; om nummers toe te voegen en te verwijderen en om de playlist nummervolgorde te bepalen.';
$lang['help_parameter_count_downloads'] = 'Whether each song played should be counted as a download in the Uploads module. When unset, direct links to the MP3 files will be used (unless no_direct_downloads is enabled).';
$lang['help_parameter_no_direct_downloads'] = 'Enable this to prevent someone finding out the direct download location of your MP3 files by accessing the playlist XSPF/XML file directly. Enabling this will disable the count_downloads parameter (downloads are always counted).';
$lang['help_parameter_playlist'] = 'playlist id to play';
$lang['help_parameter_song'] = 'upload_id of a single song to play instead of a playlist';
$lang['help_parameter_song_title'] = 'The text to replace the players default&#039;s. Only used when the song parameter is also supplied.';
$lang['help_parameter_player'] = 'the xspf player version to use (slim or extended)';
$lang['help_parameter_extended_player_url'] = 'the url of the extended version of the xspf player';
$lang['help_parameter_slim_player_url'] = 'the url of the slim version of the xspf player';
$lang['help_parameter_player_width'] = 'width of the player in pixels';
$lang['help_parameter_slim_player_height'] = 'height of the slim player in pixels';
$lang['help_parameter_extended_player_height'] = 'height of the extended player in pixels';
$lang['help_parameter_autoresume'] = 'boolean value that makes the player remember it&#039;s position';
$lang['help_parameter_autoplay'] = 'boolean value that makes the playlist load and the music start without the initial user click';
$lang['help_parameter_autoload'] = 'boolean value that makes the playlist load without the initial user click';
$lang['help_parameter_repeat_playlist'] = 'boolean value to repeat the playlist';
$lang['help_parameter_alpha'] = 'percent of color change, only works with custom color';
$lang['help_parameter_alphabetize'] = 'boolean value to alphabetize playlist';
$lang['help_parameter_buffer'] = 'seconds to preload video before playing, exclude for automatic';
$lang['help_parameter_color'] = 'six digit hex value to change the players color';
$lang['help_parameter_gotoany'] = 'boolean value that forces travel to unknown URLs';
$lang['help_parameter_image'] = 'url for a jpg image that is shown when autoplay is off';
$lang['help_parameter_info_button_text'] = 'the text to display on the info link, <a href=http://musicplayer.sourceforge.net/test/info-test.html>see this page</a>';
$lang['help_parameter_infourl'] = 'global info url for all songs, replaces playlist info urls';
$lang['help_parameter_loadurl'] = 'url linking to a text file containing all variables. cuts down on html coding and file sizes, one file can be used by many players';
$lang['help_parameter_load_message'] = 'message displayed after autoload';
$lang['help_parameter_main_image'] = 'global image url, replaces all playlist images';
$lang['help_parameter_mainurl'] = 'right-click &quot;about&quot; url';
$lang['help_parameter_no_continue'] = 'boolean value to turn off automatic song changing';
$lang['help_parameter_player_title'] = 'the text to replace the players default&#039;s';
$lang['help_parameter_repeat'] = 'boolean value to set repeat';
$lang['help_parameter_setup'] = 'boolean value to turn on special manager features such as auto-update. more to come.';
$lang['help_parameter_shuffle'] = 'boolean value to set shuffle';
$lang['help_parameter_start_track'] = 'track number for beginning track';
$lang['help_parameter_statsurl'] = 'url to an external script that can collect POST values. Can collect playSong and annotation';
$lang['help_parameter_timedisplay'] = 'numerical value to show time counter; 0:off, 1:all, 2:elapsed, 3:duration, 4:countdown';
$lang['help_parameter_useId3'] = 'boolean value that forces id3 tag use in the slim player. Can be helpful, but not recommended';
$lang['help_parameter_volume_level'] = 'starting volume level';
$lang['event_info_XSPFSongAdded'] = 'An event generated when a song is added';
$lang['event_help_XSPFSongAdded'] = '<p>An event generated when a song is added</p>
<h4>Parameters</h4>
<ul>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongChanged'] = 'An event generated when a song is modified';
$lang['event_help_XSPFSongChanged'] = '<p>An event generated when a song is modified</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
<li><em>song_name</em> - The new song name</li>
</ul> 
';
$lang['event_info_XSPFSongDeleted'] = 'An event generated when a song is deleted';
$lang['event_help_XSPFSongDeleted'] = '<p>An event generated when a song is deleted</p>
<h4>Parameters</h4>
<ul>
<li><em>song_id</em> - The song id</li>
</ul> 
';
$lang['moddescription'] = 'Enhanced XSPF Web Music Player - play MP3 on your CMS Made Simple website';
$lang['changelog'] = '<ul>
	<li>Version 0.1 Januari 2007 (dittmann). 
		<ul>
		    <li>Initial module release</li>
		</ul>
	</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>With this module you can manage a XSPF playlist to use with a xspf music player. Enhanced XSPF player is provided with the module.</p>
<h3>How Do I Use It</h3>
<p>Upload the mp3 files you want to play using the Uploads module.</p>
<p>
	<strong>To play a single song</strong><br />
	Provide the file ID from the Uploads module as song parameter - the module call will look something like this: {cms_module module=EnhancedXSPF song=4}
<p>
	<strong>To play a playlist</strong><br />
	Create one or more playlists from the module admin and include the module in your template providing the playlist id to use - the module call will look something like this: {cms_module module=EnhancedXSPF playlist=1}
	
</p>
<p>
	When you include the player in a frame (for playback without pauses when the page is changed) you can call the playlist seperately, providing a playlist parameter.<br />
	The playlist_url would look something like this: http://www.example.com/modules/EnhancedXSPF/playlist.xml.php?playlist=1
</p>
<h3>XSPF Player parameters</h3>
<p>
	All player parameters (see also xspf/xspfdoc.html inside the module directory) can be passed to the module and will be used in the player call.<br />
</p>
<h3>Support</h3>
<p>There is a number of resources available to help you with this module:
<ul>
<li>Additional discussion of this module may also be found in the <a href=&quot;http://forum.cmsmadesimple.org&quot;>CMS Made Simple Forums</a>.</li>
<li>The author, Dick Ittmann, can often be found as DeeEye in the <a href=&quot;http://cmsmadesimple.org/main/support/IRC&quot;>CMS IRC Channel</a>.</li>
</ul>
</p>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2007, Dick Ittmann. All Rights Are Reserved.</p>
<p>This module has been released under the <a href=&quot;http://www.gnu.org/licenses/licenses.html#GPL&quot;>GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utma'] = '156861353.152214359.1206628424.1211663419.1211712982.22';
$lang['utmz'] = '156861353.1211663419.21.20.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,21813.15.html|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
